﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using veebandmed1.Models;

namespace veebandmed1.Controllers
{
    public class KoersController : Controller
    {
        private KoerContext db = new KoerContext();

        public ActionResult Hoiatus() {
            return View();
        }

        // GET: Koers
        public ActionResult Index()
        {
            List<Koer> koerad = db.Koerad.ToList();
            ViewData["teade"] = "Ahoi!";
            ViewData["vanimsynniaasta"] = koerad.Min(koer => koer.synniaasta);
            ViewBag.vanimkoer = koerad.OrderBy(koer => koer.synniaasta).First();
            ViewData["keskminesynniaasta"] = koerad.Select(koer => koer.synniaasta).Average();
            ViewData["mediaan"]=koerad.Select(koer => koer.synniaasta).
                 OrderBy(synniaasta => synniaasta).
                 Skip(koerad.Count() / 2).First();
            return View(koerad);
        }

        // GET: Koers/Details/5
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Koer koer = db.Koerad.Find(id);
            if (koer == null)
            {
                return HttpNotFound();
            }
            return View(koer);
        }

        // GET: Koers/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: Koers/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see https://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "ID,koeranimi,synniaasta")] Koer koer)
        {
            if (ModelState.IsValid)
            {
                if (koer.synniaasta > 1990)
                {
                    koer.synniaasta += 1;
                    db.Koerad.Add(koer);
                }
                else {
                    return RedirectToAction("Hoiatus");
                }
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(koer);
        }

        // GET: Koers/Edit/5
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Koer koer = db.Koerad.Find(id);
            if (koer == null)
            {
                return HttpNotFound();
            }
            return View(koer);
        }

        // POST: Koers/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see https://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "ID,koeranimi,synniaasta")] Koer koer)
        {
            if (ModelState.IsValid)
            {
                db.Entry(koer).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(koer);
        }

        // GET: Koers/Delete/5
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Koer koer = db.Koerad.Find(id);
            if (koer == null)
            {
                return HttpNotFound();
            }
            return View(koer);
        }

        // POST: Koers/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            Koer koer = db.Koerad.Find(id);
            db.Koerad.Remove(koer);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
